@@ -1,6 +1,6 @@
-module.exports = function( grunt ) {
-	"use strict";
+"use strict";
 
+module.exports = function( grunt ) {
 	function readOptionalJSON( filepath ) {
 		var stripJSONComments = require( "strip-json-comments" ),
 			data = {};
@@ -15,14 +15,7 @@ module.exports = function( grunt ) {
 	var fs = require( "fs" ),
 		gzip = require( "gzip-js" ),
 		isTravis = process.env.TRAVIS,
-		oldNode = /^v6\./.test( process.version );
-
-	// Support: Node.js <8
-	// Skip running tasks that dropped support for Node.js 6
-	// in those Node versions.
-	function runIfNewNode( task ) {
-		return oldNode ? "print_old_node_message:" + task : task;
-	}
+		travisBrowsers = process.env.BROWSERS && process.env.BROWSERS.split( "," );
 
 	if ( !grunt.option( "filename" ) ) {
 		grunt.option( "filename", "jquery.js" );
@@ -48,7 +41,7 @@ module.exports = function( grunt ) {
 				retainLines: true,
 				plugins: [ "@babel/transform-for-of" ]
 			},
-			nodeSmokeTests: {
+			tests: {
 				files: {
 					"test/data/core/jquery-iterability-transpiled.js":
 						"test/data/core/jquery-iterability-transpiled-es6.js"
@@ -65,7 +58,7 @@ module.exports = function( grunt ) {
 
 				// Exclude specified modules if the module matching the key is removed
 				removeWith: {
-					ajax: [ "manipulation/_evalUrl", "event/ajax" ],
+					ajax: [ "manipulation/_evalUrl", "deprecated/ajax-event-alias" ],
 					callbacks: [ "deferred" ],
 					css: [ "effects", "dimensions", "offset" ],
 					"css/showHide": [ "effects" ],
@@ -73,6 +66,7 @@ module.exports = function( grunt ) {
 						remove: [ "ajax", "effects", "queue", "core/ready" ],
 						include: [ "core/ready-no-deferred" ]
 					},
+					event: [ "deprecated/ajax-event-alias", "deprecated/event" ],
 					sizzle: [ "css/hiddenVisibleSelectors", "effects/animatedSelector" ]
 				}
 			}
@@ -86,7 +80,7 @@ module.exports = function( grunt ) {
 					"sizzle/dist": "sizzle/dist",
 					"sizzle/LICENSE.txt": "sizzle/LICENSE.txt",
 
-					"npo/npo.js": "native-promise-only/npo.js",
+					"npo/npo.js": "native-promise-only/lib/npo.src.js",
 
 					"qunit/qunit.js": "qunit/qunit/qunit.js",
 					"qunit/qunit.css": "qunit/qunit/qunit.css",
@@ -114,7 +108,7 @@ module.exports = function( grunt ) {
 			// We have to explicitly declare "src" property otherwise "newer"
 			// task wouldn't work properly :/
 			dist: {
-				src: "dist/jquery.js"
+				src: [ "dist/jquery.js", "dist/jquery.min.js" ]
 			},
 			dev: {
 				src: [ "src/**/*.js", "Gruntfile.js", "test/**/*.js", "build/**/*.js" ]
@@ -172,6 +166,14 @@ module.exports = function( grunt ) {
 						]
 					}
 				],
+				client: {
+					qunit: {
+
+						// We're running `QUnit.start()` ourselves via `loadTests()`
+						// in test/jquery.js
+						autostart: false
+					}
+				},
 				files: [
 					"test/data/jquery-1.9.1.js",
 					"external/sinon/sinon.js",
@@ -181,39 +183,30 @@ module.exports = function( grunt ) {
 
 					"test/jquery.js",
 
-					// Replacement for testinit.js#loadTests()
-					"test/data/testrunner.js",
-					"test/unit/basic.js",
-					"test/unit/core.js",
-					"test/unit/callbacks.js",
-					"test/unit/deferred.js",
-					"test/unit/deprecated.js",
-					"test/unit/support.js",
-					"test/unit/data.js",
-					"test/unit/queue.js",
-					"test/unit/attributes.js",
-					"test/unit/event.js",
-					"test/unit/selector.js",
-					"test/unit/traversing.js",
-					"test/unit/manipulation.js",
-					"test/unit/wrap.js",
-					"test/unit/css.js",
-					"test/unit/serialize.js",
-					"test/unit/ajax.js",
-					"test/unit/effects.js",
-					"test/unit/offset.js",
-					"test/unit/dimensions.js",
-					"test/unit/animation.js",
-					"test/unit/tween.js",
-					"test/unit/ready.js",
-
-					{ pattern: "dist/jquery.*", included: false, served: true },
-					{ pattern: "src/**", included: false, served: true },
-					{ pattern: "external/**", included: false, served: true },
+					{
+						pattern: "dist/jquery.*",
+						included: false,
+						served: true,
+						nocache: true
+					},
+					{
+						pattern: "src/**",
+						included: false,
+						served: true,
+						nocache: true
+					},
+					{
+						pattern: "external/**",
+						included: false,
+						served: true,
+						nocache: true
+					},
+					{ pattern: "node_modules/**", included: false, served: true },
 					{
 						pattern: "test/**/*.@(js|css|jpg|html|xml|svg)",
 						included: false,
-						served: true
+						served: true,
+						nocache: true
 					}
 				],
 				reporters: [ "dots" ],
@@ -223,9 +216,22 @@ module.exports = function( grunt ) {
 				singleRun: true
 			},
 			main: {
+				browsers: isTravis && travisBrowsers || [ "ChromeHeadless", "FirefoxHeadless" ]
+			},
+			amd: {
+				browsers: isTravis && travisBrowsers || [ "ChromeHeadless" ],
+				options: {
+					client: {
+						qunit: {
 
-				// The Chrome sandbox doesn't work on Travis.
-				browsers: [ isTravis ? "ChromeHeadlessNoSandbox" : "ChromeHeadless" ]
+							// We're running `QUnit.start()` ourselves via `loadTests()`
+							// in test/jquery.js
+							autostart: false,
+
+							amd: true
+						}
+					}
+				}
 			},
 
 			jsdom: {
@@ -238,7 +244,7 @@ module.exports = function( grunt ) {
 						// choosing a version etc. for jsdom.
 						"dist/jquery.js",
 
-						// Replacement for testinit.js#loadTests()
+						// A partial replacement for testinit.js#loadTests()
 						"test/data/testrunner.js",
 
 						// jsdom only runs basic tests
@@ -320,13 +326,6 @@ module.exports = function( grunt ) {
 	// Integrate jQuery specific tasks
 	grunt.loadTasks( "build/tasks" );
 
-	// Support: Node.js <8
-	// Print a message on Node.js <8 notifying the task is skipped there.
-	grunt.registerTask( "print_old_node_message", function() {
-		var task = [].slice.call( arguments ).join( ":" );
-		grunt.log.writeln( "Old Node.js detected, running the task \"" + task + "\" skipped..." );
-	} );
-
 	grunt.registerTask( "lint", [
 		"jsonlint",
 
@@ -349,13 +348,16 @@ module.exports = function( grunt ) {
 	grunt.registerTask( "test:fast", "node_smoke_tests" );
 	grunt.registerTask( "test:slow", [
 		"promises_aplus_tests",
+		"karma:jsdom"
+	] );
 
-		// Support: Node.js <8
-		// Karma no longer supports Node.js <8 as it relies on async-await internally.
-		runIfNewNode( "karma:jsdom" )
+	grunt.registerTask( "test:prepare", [
+		"qunit_fixture",
+		"babel:tests"
 	] );
 
 	grunt.registerTask( "test", [
+		"test:prepare",
 		"test:fast",
 		"test:slow"
 	] );
@@ -376,7 +378,7 @@ module.exports = function( grunt ) {
 		"uglify",
 		"remove_map_comment",
 		"dist:*",
-		"qunit_fixture",
+		"test:prepare",
 		"eslint:dist",
 		"test:fast",
 		"compare_size"
