@@ -1,4 +1,4 @@
-QUnit.module( "data", { teardown: moduleTeardown } );
+QUnit.module( "data", { afterEach: moduleTeardown } );
 
 QUnit.test( "expando", function( assert ) {
 	assert.expect( 1 );
@@ -273,14 +273,14 @@ QUnit.test( ".data(object) does not retain references. #13815", function( assert
 } );
 
 QUnit.test( "data-* attributes", function( assert ) {
-	assert.expect( 43 );
+	assert.expect( 46 );
 
 	var prop, i, l, metadata, elem,
 		obj, obj2, check, num, num2,
-		parseJSON = jQuery.parseJSON,
+		parseJSON = JSON.parse,
 		div = jQuery( "<div>" ),
-		child = jQuery( "<div data-myobj='old data' data-ignored=\"DOM\" data-other='test'></div>" ),
-		dummy = jQuery( "<div data-myobj='old data' data-ignored=\"DOM\" data-other='test'></div>" );
+		child = jQuery( "<div data-myobj='old data' data-ignored=\"DOM\" data-other='test' data-foo-42='boosh'></div>" ),
+		dummy = jQuery( "<div data-myobj='old data' data-ignored=\"DOM\" data-other='test' data-foo-42='boosh'></div>" );
 
 	assert.equal( div.data( "attr" ), undefined, "Check for non-existing data-attr attribute" );
 
@@ -297,6 +297,7 @@ QUnit.test( "data-* attributes", function( assert ) {
 
 	child.appendTo( "#qunit-fixture" );
 	assert.equal( child.data( "myobj" ), "old data", "Value accessed from data-* attribute" );
+	assert.equal( child.data( "foo-42" ), "boosh", "camelCasing does not affect numbers (#1751)" );
 
 	child.data( "myobj", "replaced" );
 	assert.equal( child.data( "myobj" ), "replaced", "Original data overwritten" );
@@ -306,7 +307,7 @@ QUnit.test( "data-* attributes", function( assert ) {
 
 	obj = child.data();
 	obj2 = dummy.data();
-	check = [ "myobj", "ignored", "other" ];
+	check = [ "myobj", "ignored", "other", "foo-42" ];
 	num = 0;
 	num2 = 0;
 
@@ -335,7 +336,7 @@ QUnit.test( "data-* attributes", function( assert ) {
 
 	// attribute parsing
 	i = 0;
-	jQuery.parseJSON = function() {
+	JSON.parse = function() {
 		i++;
 		return parseJSON.apply( this, arguments );
 	};
@@ -388,7 +389,7 @@ QUnit.test( "data-* attributes", function( assert ) {
 	assert.strictEqual( child.data( "string" ), "test", "Typical string read from attribute" );
 	assert.equal( i, 2, "Correct number of JSON parse attempts when reading from attributes" );
 
-	jQuery.parseJSON = parseJSON;
+	JSON.parse = parseJSON;
 	child.remove();
 
 	// tests from metadata plugin
@@ -426,7 +427,7 @@ QUnit.test( ".data(Object)", function( assert ) {
 	assert.expect( 4 );
 
 	var obj, jqobj,
-		div = jQuery( "<div/>" );
+		div = jQuery( "<div></div>" );
 
 	div.data( { "test": "in", "test2": "in2" } );
 	assert.equal( div.data( "test" ), "in", "Verify setting an object in data" );
@@ -555,7 +556,7 @@ QUnit.test( ".data should not miss preset data-* w/ hyphenated property names",
 
 	assert.expect( 2 );
 
-	var div = jQuery( "<div/>", { id: "hyphened" } ).appendTo( "#qunit-fixture" ),
+	var div = jQuery( "<div></div>", { id: "hyphened" } ).appendTo( "#qunit-fixture" ),
 		test = {
 			"camelBar": "camelBar",
 			"hyphen-foo": "hyphen-foo"
@@ -572,7 +573,7 @@ QUnit.test( "jQuery.data should not miss data-* w/ hyphenated property names #14
 
 	assert.expect( 1 );
 
-	var div = jQuery( "<div/>" );
+	var div = jQuery( "<div></div>" );
 
 	div.data( "foo-bar", "baz" );
 
@@ -584,14 +585,14 @@ QUnit.test( ".data should not miss attr() set data-* with hyphenated property na
 
 	var a, b;
 
-	a = jQuery( "<div/>" ).appendTo( "#qunit-fixture" );
+	a = jQuery( "<div></div>" ).appendTo( "#qunit-fixture" );
 
 	a.attr( "data-long-param", "test" );
 	a.data( "long-param", { a: 2 } );
 
 	assert.deepEqual( a.data( "long-param" ), { a: 2 }, "data with property long-param was found, 1" );
 
-	b = jQuery( "<div/>" ).appendTo( "#qunit-fixture" );
+	b = jQuery( "<div></div>" ).appendTo( "#qunit-fixture" );
 
 	b.attr( "data-long-param", "test" );
 	b.data( "long-param" );
@@ -600,39 +601,143 @@ QUnit.test( ".data should not miss attr() set data-* with hyphenated property na
 	assert.deepEqual( b.data( "long-param" ), { a: 2 }, "data with property long-param was found, 2" );
 } );
 
-QUnit.test( ".data supports interoperable hyphenated/camelCase get/set of properties with arbitrary non-null|NaN|undefined values", function( assert ) {
-	var div = jQuery( "<div/>", { id: "hyphened" } ).appendTo( "#qunit-fixture" ),
+QUnit.test( ".data always sets data with the camelCased key (gh-2257)", function( assert ) {
+	assert.expect( 18 );
+
+	var div = jQuery( "<div>" ).appendTo( "#qunit-fixture" ),
 		datas = {
-			"non-empty": "a string",
-			"empty-string": "",
-			"one-value": 1,
-			"zero-value": 0,
-			"an-array": [],
-			"an-object": {},
-			"bool-true": true,
-			"bool-false": false,
+			"non-empty": {
+				key: "nonEmpty",
+				value: "a string"
+			},
+			"empty-string": {
+				key: "emptyString",
+				value: ""
+			},
+			"one-value": {
+				key: "oneValue",
+				value: 1
+			},
+			"zero-value": {
+				key: "zeroValue",
+				value: 0
+			},
+			"an-array": {
+				key: "anArray",
+				value: []
+			},
+			"an-object": {
+				key: "anObject",
+				value: {}
+			},
+			"bool-true": {
+				key: "boolTrue",
+				value: true
+			},
+			"bool-false": {
+				key: "boolFalse",
+				value: false
+			},
 
 			// JSHint enforces double quotes,
 			// but JSON strings need double quotes to parse
 			// so we need escaped double quotes here
-			"some-json": "{ \"foo\": \"bar\" }",
-			"num-1-middle": true,
-			"num-end-2": true,
-			"2-num-start": true
+			"some-json": {
+				key: "someJson",
+				value: "{ \"foo\": \"bar\" }"
+			}
+		};
+
+	jQuery.each( datas, function( key, val ) {
+		div.data( key, val.value );
+		var allData = div.data();
+		assert.equal( allData[ key ], undefined, ".data does not store with hyphenated keys" );
+		assert.equal( allData[ val.key ], val.value, ".data stores the camelCased key" );
+	} );
+} );
+
+QUnit.test( ".data should not strip more than one hyphen when camelCasing (gh-2070)", function( assert ) {
+	assert.expect( 3 );
+	var div = jQuery( "<div data-nested-single='single' data-nested--double='double' data-nested---triple='triple'></div>" ).appendTo( "#qunit-fixture" ),
+		allData = div.data();
+
+	assert.equal( allData.nestedSingle, "single", "Key is correctly camelCased" );
+	assert.equal( allData[ "nested-Double" ], "double", "Key with double hyphens is correctly camelCased" );
+	assert.equal( allData[ "nested--Triple" ], "triple", "Key with triple hyphens is correctly camelCased" );
+} );
+
+QUnit.test( ".data supports interoperable hyphenated/camelCase get/set of properties with arbitrary non-null|NaN|undefined values", function( assert ) {
+
+	var div = jQuery( "<div></div>", { id: "hyphened" } ).appendTo( "#qunit-fixture" ),
+		datas = {
+			"non-empty": {
+				key: "nonEmpty",
+				value: "a string"
+			},
+			"empty-string": {
+				key: "emptyString",
+				value: ""
+			},
+			"one-value": {
+				key: "oneValue",
+				value: 1
+			},
+			"zero-value": {
+				key: "zeroValue",
+				value: 0
+			},
+			"an-array": {
+				key: "anArray",
+				value: []
+			},
+			"an-object": {
+				key: "anObject",
+				value: {}
+			},
+			"bool-true": {
+				key: "boolTrue",
+				value: true
+			},
+			"bool-false": {
+				key: "boolFalse",
+				value: false
+			},
+
+			// JSHint enforces double quotes,
+			// but JSON strings need double quotes to parse
+			// so we need escaped double quotes here
+			"some-json": {
+				key: "someJson",
+				value: "{ \"foo\": \"bar\" }"
+			},
+
+			"num-1-middle": {
+				key: "num-1Middle",
+				value: true
+			},
+			"num-end-2": {
+				key: "numEnd-2",
+				value: true
+			},
+			"2-num-start": {
+				key: "2NumStart",
+				value: true
+			}
 		};
 
 	assert.expect( 24 );
 
 	jQuery.each( datas, function( key, val ) {
-		div.data( key, val );
+		div.data( key, val.value );
 
-		assert.deepEqual( div.data( key ), val, "get: " + key );
-		assert.deepEqual( div.data( jQuery.camelCase( key ) ), val, "get: " + jQuery.camelCase( key ) );
+		assert.deepEqual( div.data( key ), val.value, "get: " + key );
+		assert.deepEqual( div.data( val.key ), val.value, "get: " + val.key );
 	} );
 } );
 
 QUnit.test( ".data supports interoperable removal of hyphenated/camelCase properties", function( assert ) {
-	var div = jQuery( "<div/>", { id: "hyphened" } ).appendTo( "#qunit-fixture" ),
+	var div = jQuery( "<div></div>", { id: "hyphened" } ).appendTo( "#qunit-fixture" ),
+		rdashAlpha = /-([a-z])/g,
 		datas = {
 			"non-empty": "a string",
 			"empty-string": "",
@@ -651,11 +756,19 @@ QUnit.test( ".data supports interoperable removal of hyphenated/camelCase proper
 
 	assert.expect( 27 );
 
+	function fcamelCase( all, letter ) {
+		return letter.toUpperCase();
+	}
+
 	jQuery.each( datas, function( key, val ) {
 		div.data( key, val );
 
 		assert.deepEqual( div.data( key ), val, "get: " + key );
-		assert.deepEqual( div.data( jQuery.camelCase( key ) ), val, "get: " + jQuery.camelCase( key ) );
+		assert.deepEqual(
+			div.data( key.replace( rdashAlpha, fcamelCase ) ),
+			val,
+			"get: " + key.replace( rdashAlpha, fcamelCase )
+		);
 
 		div.removeData( key );
 
@@ -694,7 +807,7 @@ QUnit.test( ".data supports interoperable removal of properties SET TWICE #13850
 	} );
 } );
 
-QUnit.test( ".removeData supports removal of hyphenated properties via array (#12786)", function( assert ) {
+QUnit.test( ".removeData supports removal of hyphenated properties via array (#12786, gh-2257)", function( assert ) {
 	assert.expect( 4 );
 
 	var div, plain, compare;
@@ -702,12 +815,11 @@ QUnit.test( ".removeData supports removal of hyphenated properties via array (#1
 	div = jQuery( "<div>" ).appendTo( "#qunit-fixture" );
 	plain = jQuery( {} );
 
-	// When data is batch assigned (via plain object), the properties
-	// are not camel cased as they are with (property, value) calls
+	// Properties should always be camelCased
 	compare = {
 
 		// From batch assignment .data({ "a-a": 1 })
-		"a-a": 1,
+		"aA": 1,
 
 		// From property, value assignment .data( "b-b", 1 )
 		"bB": 1
@@ -723,23 +835,22 @@ QUnit.test( ".removeData supports removal of hyphenated properties via array (#1
 	div.removeData( [ "a-a", "b-b" ] );
 	plain.removeData( [ "a-a", "b-b" ] );
 
-	// NOTE: Timo's proposal for "propEqual" (or similar) would be nice here
 	assert.deepEqual( div.data(), {}, "Data is empty. (div)" );
 	assert.deepEqual( plain.data(), {}, "Data is empty. (plain)" );
 } );
 
 // Test originally by Moschel
 QUnit.test( ".removeData should not throw exceptions. (#10080)", function( assert ) {
+	var done = assert.async();
 	assert.expect( 1 );
-	QUnit.stop();
 	var frame = jQuery( "#loadediframe" );
 	jQuery( frame[ 0 ].contentWindow ).on( "unload", function() {
 		assert.ok( true, "called unload" );
-		QUnit.start();
+		done();
 	} );
 
 	// change the url to trigger unload
-	frame.attr( "src", "data/iframe.html?param=true" );
+	frame.attr( "src", baseURL + "iframe.html?param=true" );
 } );
 
 QUnit.test( ".data only checks element attributes once. #8909", function( assert ) {
@@ -819,10 +930,10 @@ QUnit.test( "Check proper data removal of non-element descendants nodes (#8335)"
 	assert.ok( !text.data( "test" ), "Be sure data is not stored in non-element" );
 } );
 
-testIframeWithCallback(
+testIframe(
 	"enumerate data attrs on body (#14894)",
 	"data/dataAttrs.html",
-	function( result, assert ) {
+	function( assert, jQuery, window, document, result ) {
 		assert.expect( 1 );
 		assert.equal( result, "ok", "enumeration of data- attrs on body" );
 	}
@@ -832,7 +943,7 @@ QUnit.test( "Check that the expando is removed when there's no more data", funct
 	assert.expect( 2 );
 
 	var key,
-		div = jQuery( "<div/>" );
+		div = jQuery( "<div></div>" );
 	div.data( "some", "data" );
 	assert.equal( div.data( "some" ), "data", "Data is added" );
 	div.removeData( "some" );
@@ -866,7 +977,7 @@ QUnit.test( ".data(prop) does not create expando", function( assert ) {
 	assert.expect( 1 );
 
 	var key,
-		div = jQuery( "<div/>" );
+		div = jQuery( "<div></div>" );
 
 	div.data( "foo" );
 	assert.equal( jQuery.hasData( div[ 0 ] ), false, "No data exists after access" );
@@ -879,11 +990,20 @@ QUnit.test( ".data(prop) does not create expando", function( assert ) {
 	}
 } );
 
-QUnit.test( ".data(camelCase) retrieves hyphenated keys", function( assert ) {
-	assert.expect( 1 );
+QUnit.test( ".data() returns a regular object (jQuery <4 only, gh-4665)", function( assert ) {
+	assert.expect( 4 );
 
-	var div = jQuery( "<div/>" );
+	function verifyRegularObject( assert, object ) {
+		assert.strictEqual( object.hasOwnProperty, Object.prototype.hasOwnProperty,
+			"Data object has the hasOwnProperty method" );
+		assert.strictEqual( object + "", "[object Object]",
+			"Data object can be stringified" );
+	}
 
-	jQuery.data( div[ 0 ], "data-test", "data" );
-	assert.equal( div.data( "dataTest" ), "data" );
+	var elem = jQuery( "<div></div>" );
+
+	verifyRegularObject( assert, elem.data() );
+
+	elem.data( "foo", "bar" );
+	verifyRegularObject( assert, elem.data() );
 } );
