@@ -55,7 +55,7 @@ testIframe(
 );
 
 ( function() {
-	var expected,
+	var browserKey, expected,
 		userAgent = window.navigator.userAgent,
 		expectedMap = {
 			edge: {
@@ -68,11 +68,13 @@ testIframe(
 				"createHTMLDocument": true,
 				"focusin": false,
 				"noCloneChecked": true,
+				"option": true,
 				"optSelected": true,
 				"pixelBoxStyles": true,
 				"pixelPosition": true,
 				"radioValue": true,
 				"reliableMarginLeft": true,
+				"reliableTrDimensions": false,
 				"scrollboxSize": true
 			},
 			ie_10_11: {
@@ -85,11 +87,13 @@ testIframe(
 				"createHTMLDocument": true,
 				"focusin": true,
 				"noCloneChecked": false,
+				"option": true,
 				"optSelected": false,
 				"pixelBoxStyles": true,
 				"pixelPosition": true,
 				"radioValue": false,
 				"reliableMarginLeft": true,
+				"reliableTrDimensions": false,
 				"scrollboxSize": true
 			},
 			ie_9: {
@@ -102,11 +106,13 @@ testIframe(
 				"createHTMLDocument": true,
 				"focusin": true,
 				"noCloneChecked": false,
+				"option": false,
 				"optSelected": false,
 				"pixelBoxStyles": true,
 				"pixelPosition": true,
 				"radioValue": false,
 				"reliableMarginLeft": true,
+				"reliableTrDimensions": false,
 				"scrollboxSize": false
 			},
 			chrome: {
@@ -119,11 +125,13 @@ testIframe(
 				"createHTMLDocument": true,
 				"focusin": false,
 				"noCloneChecked": true,
+				"option": true,
 				"optSelected": true,
 				"pixelBoxStyles": true,
 				"pixelPosition": true,
 				"radioValue": true,
 				"reliableMarginLeft": true,
+				"reliableTrDimensions": true,
 				"scrollboxSize": true
 			},
 			safari: {
@@ -136,11 +144,13 @@ testIframe(
 				"createHTMLDocument": true,
 				"focusin": false,
 				"noCloneChecked": true,
+				"option": true,
 				"optSelected": true,
 				"pixelBoxStyles": true,
 				"pixelPosition": true,
 				"radioValue": true,
 				"reliableMarginLeft": true,
+				"reliableTrDimensions": true,
 				"scrollboxSize": true
 			},
 			safari_9_10: {
@@ -153,11 +163,13 @@ testIframe(
 				"createHTMLDocument": true,
 				"focusin": false,
 				"noCloneChecked": true,
+				"option": true,
 				"optSelected": true,
 				"pixelBoxStyles": false,
 				"pixelPosition": false,
 				"radioValue": true,
 				"reliableMarginLeft": true,
+				"reliableTrDimensions": true,
 				"scrollboxSize": true
 			},
 			firefox: {
@@ -170,11 +182,13 @@ testIframe(
 				"createHTMLDocument": true,
 				"focusin": false,
 				"noCloneChecked": true,
+				"option": true,
 				"optSelected": true,
 				"pixelBoxStyles": true,
 				"pixelPosition": true,
 				"radioValue": true,
 				"reliableMarginLeft": true,
+				"reliableTrDimensions": true,
 				"scrollboxSize": true
 			},
 			firefox_60: {
@@ -187,11 +201,13 @@ testIframe(
 				"createHTMLDocument": true,
 				"focusin": false,
 				"noCloneChecked": true,
+				"option": true,
 				"optSelected": true,
 				"pixelBoxStyles": true,
 				"pixelPosition": true,
 				"radioValue": true,
 				"reliableMarginLeft": false,
+				"reliableTrDimensions": true,
 				"scrollboxSize": true
 			},
 			ios: {
@@ -204,11 +220,13 @@ testIframe(
 				"createHTMLDocument": true,
 				"focusin": false,
 				"noCloneChecked": true,
+				"option": true,
 				"optSelected": true,
 				"pixelBoxStyles": true,
 				"pixelPosition": true,
 				"radioValue": true,
 				"reliableMarginLeft": true,
+				"reliableTrDimensions": true,
 				"scrollboxSize": true
 			},
 			ios_9_10: {
@@ -221,11 +239,13 @@ testIframe(
 				"createHTMLDocument": true,
 				"focusin": false,
 				"noCloneChecked": true,
+				"option": true,
 				"optSelected": true,
 				"pixelBoxStyles": false,
 				"pixelPosition": false,
 				"radioValue": true,
 				"reliableMarginLeft": true,
+				"reliableTrDimensions": true,
 				"scrollboxSize": true
 			},
 			ios_8: {
@@ -238,11 +258,13 @@ testIframe(
 				"createHTMLDocument": false,
 				"focusin": false,
 				"noCloneChecked": true,
+				"option": true,
 				"optSelected": true,
 				"pixelBoxStyles": false,
 				"pixelPosition": false,
 				"radioValue": true,
 				"reliableMarginLeft": true,
+				"reliableTrDimensions": true,
 				"scrollboxSize": true
 			},
 			ios_7: {
@@ -255,11 +277,13 @@ testIframe(
 				"createHTMLDocument": true,
 				"focusin": false,
 				"noCloneChecked": true,
+				"option": true,
 				"optSelected": true,
 				"pixelBoxStyles": false,
 				"pixelPosition": false,
 				"radioValue": true,
 				"reliableMarginLeft": true,
+				"reliableTrDimensions": true,
 				"scrollboxSize": true
 			},
 			android: {
@@ -272,15 +296,25 @@ testIframe(
 				"createHTMLDocument": true,
 				"focusin": false,
 				"noCloneChecked": true,
+				"option": true,
 				"optSelected": true,
 				"pixelBoxStyles": false,
 				"pixelPosition": false,
 				"radioValue": true,
 				"reliableMarginLeft": false,
+				"reliableTrDimensions": true,
 				"scrollboxSize": true
 			}
 		};
 
+	// Make the slim build pass tests.
+	for ( browserKey in expectedMap ) {
+		if ( !jQuery.ajax ) {
+			delete expectedMap[ browserKey ].ajax;
+			delete expectedMap[ browserKey ].cors;
+		}
+	}
+
 	if ( /edge\//i.test( userAgent ) ) {
 		expected = expectedMap.edge;
 	} else if ( /(msie 10\.0|trident\/7\.0)/i.test( userAgent ) ) {
@@ -292,24 +326,24 @@ testIframe(
 		// Catches Chrome on Android as well (i.e. the default
 		// Android browser on Android >= 4.4).
 		expected = expectedMap.chrome;
-	} else if ( /\b(?:11|12)\.\d(\.\d+)* safari/i.test( userAgent ) ) {
-		expected = expectedMap.safari;
-	} else if ( /\b(?:9|10)\.\d(\.\d+)* safari/i.test( userAgent ) ) {
+	} else if ( /\b(?:9|10)\.\d+(\.\d+)* safari/i.test( userAgent ) ) {
 		expected = expectedMap.safari_9_10;
-	} else if ( /firefox\/(?:52|60)/i.test( userAgent ) ) {
+	} else if ( /firefox\/(?:4\d|5\d|60)/i.test( userAgent ) ) {
 		expected = expectedMap.firefox_60;
 	} else if ( /firefox/i.test( userAgent ) ) {
 		expected = expectedMap.firefox;
-	} else if ( /(?:iphone|ipad);.*(?:iphone)? os (?:11|12)_/i.test( userAgent ) ) {
-		expected = expectedMap.ios;
+	} else if ( /android 4\.[0-3]/i.test( userAgent ) ) {
+		expected = expectedMap.android;
 	} else if ( /iphone os (?:9|10)_/i.test( userAgent ) ) {
 		expected = expectedMap.ios_9_10;
 	} else if ( /iphone os 8_/i.test( userAgent ) ) {
 		expected = expectedMap.ios_8;
 	} else if ( /iphone os 7_/i.test( userAgent ) ) {
 		expected = expectedMap.ios_7;
-	} else if ( /android 4\.[0-3]/i.test( userAgent ) ) {
-		expected = expectedMap.android;
+	} else if ( /(?:iphone|ipad);.*(?:iphone)? os \d+_/i.test( userAgent ) ) {
+		expected = expectedMap.ios;
+	} else if ( /\b\d+(\.\d+)+ safari/i.test( userAgent ) ) {
+		expected = expectedMap.safari;
 	}
 
 	QUnit.test( "Verify that support tests resolve as expected per browser", function( assert ) {
